#!/usr/bin/env python3

"""
BRS-XSS CLI Module

Command line interface for the BRS-XSS scanner.

Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Modified: Sat 02 Aug 2025 09:35:54 MSK
Telegram: https://t.me/EasyProTech
"""